/**
 * useInterval - A hook that allows you to run a function at specified intervals.
 *
 * This hook abstracts away the complexity of setting up and tearing down intervals,
 * making it easier to use intervals within your React components. It handles cleanup
 * automatically and ensures that interval callbacks are always using the latest props
 * and state without needing to reset the interval.
 *
 * @param callback - The function to be executed at each interval.
 * @param delay - The interval duration in milliseconds. If null, the interval will be paused.
 *
 * Example Usage:
 * ```tsx
 * useInterval(() => {
 *   // Your interval task here
 * }, 1000);
 * ```
 */
export declare const useInterval: (callback: () => void, delay: number | null) => void;
