import { type ScrollPositionState } from './type';
/**
 * useScrollPosition - Monitors and returns the window's current vertical scroll position.
 *
 * This hook sets up an event listener for the window's `scroll` event to track vertical scroll position changes.
 * It's safe for use in environments that support the `window` object, including considerations for SSR (Server-Side Rendering).
 * Upon mount, the hook immediately updates to the current scroll position and provides real-time updates as the user scrolls.
 *
 * @returns {scrollYPosition: number} - The current vertical scroll position of the window.
 *
 * Example:
 * ```
 * const { scrollYPosition } = useScrollPosition();
 * ```
 */
export declare const useScrollPosition: () => ScrollPositionState;
